@@ -11,9 +11,8 @@ Copyright © Semantyk 2020. All rights reserved.\
 –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
 """
 
-from . import bnode, identifier, literal, uriref, variable
+from . import bnode, identifier, literal, uriref
 from .bnode import *
 from .identifier import *
 from .literal import *
-from .uriref import *
-from .variable import *
\ No newline at end of file
+from .uriref import *
\ No newline at end of file
