@@ -16,6 +16,7 @@ __all__ = [
     'DCTERMS',
     'DOAP',
     'FOAF',
+    'Namespace',
     'OWL',
     'RDF',
     'RDFS',
@@ -25,8 +26,31 @@ __all__ = [
     'VOID'
 ]
 
+from .identifier.uriref import URIRef
 from rdflib import Namespace
 
+class Namespace(str):
+    @property
+    def title(self):
+        return URIRef(self + 'title')
+
+    def term(self, name):
+        return URIRef(self + name) if isinstance(name, str) else self
+
+    def __getattr__(self, name):
+        if name.startswith('__'):
+            raise AttributeError
+        return self.term(name)
+
+    def __getitem__(self, key):
+        return self.term(key)
+
+    def __new__(cls, value):
+        return str.__new__(cls, value)
+
+    def __repr__(self):
+        return "Namespace('%s')" % self
+
 DC = Namespace('http://purl.org/dc/elements/1.1/')
 DCTERMS = Namespace('http://purl.org/dc/terms/')
 DOAP = Namespace('http://usefulinc.com/ns/doap#')
